package com.ruoyi.system.service.impl;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.PoUser;
import com.ruoyi.system.mapper.PoUserMapper;
import com.ruoyi.system.service.IPoUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 用户Service业务层处理
 *
 * @author ruoyi
 * @date 2023-01-17
 */
@Service
public class PoUserServiceImpl implements IPoUserService
{
    @Autowired
    private PoUserMapper poUserMapper;

    /**
     * 查询用户
     *
     * @param userId 用户主键
     * @return 用户
     */
    @Override
    public PoUser selectPoUserByUserId(String userId)
    {
        return poUserMapper.selectPoUserByUserId(userId);
    }

    /**
     * 查询用户列表
     *
     * @param poUser 用户
     * @return 用户
     */
    @Override
    public List<PoUser> selectPoUserList(PoUser poUser)
    {
        return poUserMapper.selectPoUserList(poUser);
    }

    /**
     * 新增用户
     *
     * @param poUser 用户
     * @return 结果
     */
    @Override
    public int insertPoUser(PoUser poUser)
    {
        poUser.setCreateTime(DateUtils.getNowDate());
        return poUserMapper.insertPoUser(poUser);
    }

    /**
     * 修改用户
     *
     * @param poUser 用户
     * @return 结果
     */
    @Override
    public int updatePoUser(PoUser poUser)
    {
        poUser.setUpdateTime(DateUtils.getNowDate());
        return poUserMapper.updatePoUser(poUser);
    }

    /**
     * 批量删除用户
     *
     * @param userIds 需要删除的用户主键
     * @return 结果
     */
    @Override
    public int deletePoUserByUserIds(String[] userIds)
    {
        return poUserMapper.deletePoUserByUserIds(userIds);
    }

    /**
     * 删除用户信息
     *
     * @param userId 用户主键
     * @return 结果
     */
    @Override
    public int deletePoUserByUserId(String userId)
    {
        return poUserMapper.deletePoUserByUserId(userId);
    }
}
